==> rivendell-2.9.2.tar.gz: rivendell-2.9.2/rdlogin/rdlogin_pt_BR.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation>RDLogin - Estação:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation>rdlogin : </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi possível conectar</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Usuário atual: Desconhecido</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Usuário:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Escolher 
Usuário</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>&amp;Usuário
Padrão</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation>Usuário Atual:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation>Senha Inválida!</translation>
    </message>
</context>
</TS>

==> rivendell-2.19.1.tar.gz: rivendell-2.19.1/rdlogin/rdlogin_pt_BR.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation>RDLogin - Estação:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation>rdlogin : </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi possível conectar</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Usuário atual: Desconhecido</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Usuário:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Escolher 
Usuário</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>&amp;Usuário
Padrão</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation>Usuário Atual:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Senha Inválida!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
